From: Jens Rottmann <JRottmann@LiPPERTEmbedded.de>
To: Thomas Gleixner <tglx@linutronix.de>
Cc: John Stultz <johnstul@us.ibm.com>, linux-kernel@vger.kernel.org
Subject: [PATCH] cs5535-clockevt: typo, it's MFGPT, not MFPGT
Date: Wed, 04 Jul 2012 14:22:54 +0200 [thread overview]
Message-ID: <4FF4359E.6030808@LiPPERTEmbedded.de> (raw)
cs5535-clockevt: typo, it's MFGPT, not MFPGT
Had me fooled for a while, "dmesg|grep -i mfgpt" wouldn't show anything.
Signed-off-by: Jens Rottmann <JRottmann@LiPPERTEmbedded.de>
---
--- linux-3.4/drivers/clocksource/cs5535-clockevt.c
+++ mfgpt_typo/drivers/clocksource/cs5535-clockevt.c
@@ -53,7 +53,7 @@
#define MFGPT_PERIODIC (MFGPT_HZ / HZ)
/*
* The MFPGT timers on the CS5536 provide us with suitable timers to use
* as clock event sources - not as good as a HPET or APIC, but certainly
* better than the PIT. This isn't a general purpose MFGPT driver, but
* a simplified one designed specifically to act as a clock event source.
@@ -144,7 +144,7 @@
timer = cs5535_mfgpt_alloc_timer(MFGPT_TIMER_ANY, MFGPT_DOMAIN_WORKING);
if (!timer) {
- printk(KERN_ERR DRV_NAME ": Could not allocate MFPGT timer\n");
+ printk(KERN_ERR DRV_NAME ": Could not allocate MFGPT timer\n");
return -ENODEV;
}
cs5535_event_clock = timer;
_
reply other threads:[~2012-07-04 12:38 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=4FF4359E.6030808@LiPPERTEmbedded.de \
--to=jrottmann@lippertembedded.de \
--cc=johnstul@us.ibm.com \
--cc=linux-kernel@vger.kernel.org \
--cc=tglx@linutronix.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -53,7 +53,7 @@
#define MFGPT_PERIODIC (MFGPT_HZ / HZ)
/*
- * The MFPGT timers on the CS5536 provide us with suitable timers to use
+ * The MFGPT timers on the CS5536 provide us with suitable timers to use
* as clock event sources - not as good as a HPET or APIC, but certainly
* better than the PIT. This isn't a general purpose MFGPT driver, but
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox